@@ -22,23 +22,26 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-import requests
 import random
 from .enums import Enum
 from .errors import *
+from .http_tenor import TenorHttp
 BASE_URL_SEARCH = "https://g.tenor.com/v1/search"
 BASE_URL_TRENDING = "https://g.tenor.com/v1/trending"
 BASE_URL_RANDOM =  "https://g.tenor.com/v1/random"
 BASE_URL_GIF = "https://g.tenor.com/v1/gifs?"
-HEADERS = {'content-type': 'application/json'} 
-API_KEY = "2SEYM2O49WBY"
 
 class Tapi:
     """[Tenor api wrapper used to request gif's from the website]
         This was original made to be used with discord.py bot development
         Why? , Cause i felt like it
     """
+    def __init__(self , api_key = None):
+        assert api_key , "Please provide an API KEY"
+        self.api = api_key
+        self.__session = TenorHttp() 
 
+    
     def __get_url_from_response(
         self , 
         response: dict , 
@@ -47,15 +50,11 @@ class Tapi:
     ) -> tuple: 
         if response.get("code") == 5: 
             raise DoesNotExist("THE GIF ID OR NAME COULD NOT BE FOUND")
+    
+        urls = tuple((response['results'][index]['media'][0][mediafilter]['url'] for index in range(limit)))
+        return urls
 
-        __tenor_urls = [] 
-        for index in range(limit): 
-            url = response['results'][index]['media'][0][mediafilter]['url']
-            __tenor_urls.append(url)
-
-        return tuple(__tenor_urls)
-
-    def tenor_search_request(
+    async def tenor_search_request(
         self , *,
         query: str ,
         limit: int = 5 , 
@@ -77,17 +76,14 @@ class Tapi:
         Returns:
             tuple[str]: [GIF URLS]
         """
-        data = requests.get(
+        data = await self.__session.request(
             url = "%s?q=%s&limit=%s&contentfilter=%s&mediafilter=%s&pos=%s&locale=%s&key=%s"
             % 
-            (BASE_URL_SEARCH , query , limit , contentfilter , mediafilter , pos , locale , API_KEY) , 
-
-            headers = HEADERS
-        ).json()
-
+            (BASE_URL_SEARCH , query , limit , contentfilter , mediafilter , pos , locale , self.api)
+        )
         return self.__get_url_from_response(data , limit , mediafilter)
 
-    def tenor_trending_request(
+    async def tenor_trending_request(
         self , *,
         limit: int = 5 , 
         contentfilter: Enum = Enum.ContentFilter.OFF , 
@@ -105,17 +101,15 @@ class Tapi:
         Returns:
             tuple[str]: [GIF URLS]
         """
-        data = requests.get(
+        data = await self.__session.request(
             url = "%s?limit=%s&contentfilter=%s&mediafilter=%s&locale=%s&key=%s"
             % 
-            (BASE_URL_TRENDING , limit , contentfilter , mediafilter , locale , API_KEY) , 
-
-            headers = HEADERS
-        ).json()
+            (BASE_URL_TRENDING , limit , contentfilter , mediafilter , locale , self.api)
+        )
 
         return self.__get_url_from_response(data , limit , mediafilter)
 
-    def custom_random_request(
+    async def custom_random_request(
         self , *,
         query: str ,
         limit: int = 5 , 
@@ -137,19 +131,18 @@ class Tapi:
         Returns:
             tuple[str]: [GIF URLS]
         """
-        pos = str(random.randint(0 , pos))
-        data = requests.get(
-            url = "%s?q=%s&limit=%s&contentfilter=%s&mediafilter=%s&pos=%s&locale=%s&key=%s"
-            % 
-            (BASE_URL_RANDOM , query , limit , contentfilter , mediafilter , pos , locale , API_KEY) , 
 
-            headers = HEADERS
-        ).json()
-
-        return self.__get_url_from_response(data , limit , mediafilter)
+        return await self.tenor_random_request(
+            query=query,
+            limit=limit,
+            contentfilter=contentfilter,
+            mediafilter=mediafilter,
+            pos=random.randint(0 , pos),
+            locale=locale,
+        )
 
 
-    def tenor_random_request(
+    async def tenor_random_request(
         self , *,
         query: str ,
         limit: int = 5 , 
@@ -171,17 +164,15 @@ class Tapi:
         Returns:
             tuple[str]: [GIF URLS]
         """
-        data = requests.get(
+        data = await self.__session.request(
             url = "%s?q=%s&limit=%s&contentfilter=%s&mediafilter=%s&pos=%s&locale=%s&key=%s"
             % 
-            (BASE_URL_RANDOM , query , limit , contentfilter , mediafilter , pos , locale , API_KEY) , 
-
-            headers = HEADERS
-        ).json()
+            (BASE_URL_RANDOM , query , limit , contentfilter , mediafilter , pos , locale , self.api)
+        )
 
         return self.__get_url_from_response(data , limit , mediafilter)
 
-    def tenor_gif_request(
+    async def tenor_gif_request(
         self , *,
         ids: int ,
         limit: int = 5 , 
@@ -197,11 +188,10 @@ class Tapi:
         Returns:
             tuple[str]: [GIF URLS]
         """
-        data = requests.get(
+        data = await self.__session.request(
             url = "%s?ids=%s&limit=%s&mediafilter=%s&key=%s"
             % 
-            (BASE_URL_GIF , ids , limit ,  mediafilter , API_KEY) , 
+            (BASE_URL_GIF , ids , limit ,  mediafilter , self.api)
+        )
 
-            headers = HEADERS
-        ).json()
         return self.__get_url_from_response(data , limit , mediafilter)
\ No newline at end of file
